@@ -997,8 +997,8 @@ def example1():
 
 def example2():
     """
-    A 300 THz wave is at an air-metal interface, where the metal is
-    metal and insulator are anisotropic and magnetic. Goal: Find the modes
+    A 300 THz wave is at an air-metal interface, where the metal is anisotropic
+    and magnetic. Goal: Same as example1()
     """
     params = {'w': 2 * pi * 300 * nu.THz,
               'd_list': [inf, inf],
@@ -1035,4 +1035,4 @@ def example2():
         except:
             print('kx =', '(%.4g+%.4gj) rad/um' % (kx.real / nu.um**-1, kx.imag / nu.um**-1),
                   'seems not to be a real mode (a local minimum '
-                  + 'but not a zero in the error function)')
\ No newline at end of file
+                  + 'but not a zero in the error function)')
